@@ -1198,18 +1198,21 @@ drop_internal_applet (PanelWidget *panel, int pos, const char *applet_type,
 }
 
 static void
-drop_color(PanelWidget *panel, int pos, guint16 *dropped)
+drop_color (PanelWidget *panel,
+	    int          pos,
+	    guint16     *dropped)
 {
-	GdkColor c;
+	PanelColor c;
 
-	if(!dropped) return;
+	if (!dropped)
+		return;
 
-	c.red = dropped[0];
-	c.green = dropped[1];
-	c.blue = dropped[2];
-	c.pixel = 0;
+	c.red   = dropped [0];
+	c.green = dropped [1];
+	c.blue  = dropped [2];
+	c.alpha = 65535;
 
-	panel_widget_set_back_color(panel, &c);
+	panel_widget_set_back_color (panel, &c);
 }
 
 static GtkTargetList *
@@ -1971,7 +1974,8 @@ panel_load_panels_from_gconf (void)
 		PanelBackType  back_type;
 		BasePState     state;
 		BasePMode      mode;
-		GdkColor       back_color = {0,0,0,1};
+		PanelColor     back_color = {0, 0, 0, 0xFFFF};
+		GdkColor       gdkcolor = {0, 0, 0, 1};
 		gboolean       fit_pixmap_bg;
 		gboolean       stretch_pixmap_bg;
 		gboolean       rotate_pixmap_bg;
@@ -2009,10 +2013,17 @@ panel_load_panels_from_gconf (void)
 		}
 
 		tmp_str = panel_get_string (profile, panel_id, "panel_background_color", NULL);
-		if (!string_empty (tmp_str))
-			gdk_color_parse (tmp_str, &back_color);
+		if (!tmp_str || !tmp_str [0]) {
+			gdk_color_parse (tmp_str, &gdkcolor);
+			back_color.red   = gdkcolor.red;
+			back_color.green = gdkcolor.green;
+			back_color.blue  = gdkcolor.blue;
+		}
 		g_free (tmp_str);
 
+		back_color.alpha = panel_get_int (
+					profile, panel_id, "panel_background_color_alpha", 0xFFFF);
+
 		tmp_str = panel_get_string (
 				profile, panel_id, "panel_background_type", "no_background");
 		gconf_string_to_enum (background_type_enum_map, tmp_str, (int *) &back_type);
@@ -2332,6 +2343,10 @@ panel_save_to_gconf (PanelData *pd)
 			  "panel_background_color", color);
 	g_free (color);
 
+	panel_set_int (profile, panel->unique_id,
+		       "panel_background_color_alpha",
+		       panel->back_color.alpha);
+
 	panel_set_string (profile, panel->unique_id,
 			  "panel_background_type", 
 			  gconf_enum_to_string (background_type_enum_map, panel->back_type));
@@ -2417,8 +2432,6 @@ panel_remove_from_gconf (PanelWidget *panel)
         gconf_client_set_list (panel_gconf_get_client (), key,
 			       GCONF_VALUE_STRING, new_panels, NULL);
 
-	gconf_client_suggest_sync (panel_gconf_get_client (), NULL);
-
 	if (new_panels)
 		panel_g_slist_deep_free (new_panels);
 }
